###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#   As described by M.C. Ferris and A.B. Philpott
#	in "An Interior Point Algorithm for Semi-Infinite
#		  Linear Programming"
#    Mathematical Programming vol. 43, pp. 257-276, 1989
#
#   Problem of section 2.4
#    Coded by A. Ismael F. Vaz 27/02/2000  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of x vars
param nx;
#number of t
param nt;

# initial guess
param xinit{1..nx};
param tinit{1..nt};

# x variables
var x {i in 1..nx} := xinit[i];
# t variable
var t {j in 1..nt} := tinit[j];

minimize fx:
	(sum {i in 1..7} (x[i]/i));

subject to tcons:
	(sum {i in 1..7} (-t[1]^(i-1)*x[i]))-(sum {i in 0..4} (t[1]^(2*i)))<=0;

subject to bounds:
	0 <= t[1] <= 1;

data;

param nx := 7;
param nt := 1;

# inital guess
param xinit:=
	1 0
	2 0
	3 0
	4 0
	5 0
	6 0
	7 0;
param tinit:=
	1 0;

# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "f=%lf\n", -1.78688;
