###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  Hettich set of SIP problems (Chebyshev approximation problems)
#   As described by R. Hettich, "A comparison of some numerical methods
#                                for semi-infinite programming",
#   in R. Hettich (eds.), "Semi-infinite Programming",
#    Lecture notes in Control and Information Sciences no. 15, pp. 112-125
#    Springer Verlag, Berlin (1979)
#
#   Example 6
#    Coded by A. Ismael F. Vaz 27/12/1999  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of p vars
param np := 2;
#number of t
param nt := 2;

# p variables
var p {1..np};
# t variable
var t {1..nt};
# d distance
var d;

minimize dp:
	d;

subject to tcons1:
	-(t[1]^2+t[2]^2
	-(p[1]*sqrt(t[1]^2+t[2]^2)+p[2]*exp(sqrt(t[1]^2+t[2]^2))))-d <=0;
subject to tcons2:
	(t[1]^2+t[2]^2
	-(p[1]*sqrt(t[1]^2+t[2]^2)+p[2]*exp(sqrt(t[1]^2+t[2]^2))))-d <=0;
subject to bounds {i in 1..nt}:
	1e-10 <= t[i] <= sqrt(2);

data;

var d := 0.6;
var p := 1	0
	2	1;

###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display p;
display dp;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "p=(%lf,%lf) dp=%lf\n", 0.148, 0.418, 0.538;
