###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  Hettich set of SIP problems (Chebyshev approximation problems)
#   As described by R. Hettich, "An Implementation of a Discretization Method
#                                for Semi-Infinite Programming",
#   in Mathematical Programming 34(1986) 354-361
#
#   Example 2
#    Coded by A. Ismael F. Vaz 30/12/1999  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# degree of polynomial d=2..7 was tested by Hettich
param d := 2;

#number of t
param nt := 2;

# x variables
# extra variables for ex. x[0,2] are eliminated by presolver
var x {0..d,0..d};
# t variable
var t {1..nt};
# distance variable
var dist;

minimize distance:
	dist;

subject to tcons1:
	-(sum {i in 0..d} ( sum {j in 0..i} (x[i,j]*t[1]^(i-j)*t[2]^j))
          -((1+t[1])^t[2]))-dist <= 0;
subject to tcons2:
	(sum {i in 0..d} ( sum {j in 0..i} (x[i,j]*t[1]^(i-j)*t[2]^j))
          -((1+t[1])^t[2]))-dist <= 0;
subject to bound1:
	0 <= t[1] <= 1;
subject to bound2:
	1 <= t[2] <= 2.5;


###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display dist;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
# d=2
printf "dist=%lf\n", 1.78e-1;
# d=3
#printf "dist=%lf\n", 3.66e-2;
# d=4
#printf "dist=%lf\n", 4.68e-3;
# d=5
#printf "dist=%lf\n", 7.39e-4;
# d=6
#printf "dist=%lf\n", 7.68e-5;
# d=7
#printf "dist=%lf\n", 8.81e-6;

