###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  As described by K.O. Kortanek and H. No in
#      "A central cutting plane algorithm for convex semi-infinite
#               programming problems"
#    SIAM Journal on Optimization, vol. 3, no. 4, pp. 901-918, 1993
#
#   Example 1
#
#    Coded by A. Ismael F. Vaz 03/06/2002  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# PI
param pi := atan(1)*4;

#number of x vars
param nx := 2;
#number of t vars
param nt := 1;

# x variables
var x {1..nx};
# t variable
var t {1..nt};

minimize obj:
    (x[1]-2)^2+(x[2]-0.2)^2;

subject to tcons:
    ((5*sin(pi*sqrt(t[1])))/(1+t[1]^2))*x[1]^2-x[2] <= 0;
subject to xbound1:
    -1 <= x[1] <=1;
subject to xbound2:
    0 <= x[2] <= 0.2;
subject to bounds {i in 1..nt}:
    # original lower bound is zero, but sqrt is not differentiable
    0.000001 <= t[i] <= 8;


###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display x;
display obj;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf, %lf) obj=%lf\n", 0.205236774, 0.2, 3.22117504;
# Dual solution, l=1.84175707 when t=0.213412466
