###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  As described by K.O. Kortanek and H. No in
#      "A central cutting plane algorithm for convex semi-infinite
#               programming problems"
#    SIAM Journal on Optimization, vol. 3, no. 4, pp. 901-918, 1993
#
#   Example 4
#
#    Coded by A. Ismael F. Vaz 03/06/2002  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# PI/4
param pi4 := atan(1);

#number of x vars
param nx := 7;
#number of t vars
param nt := 1;

# x variables
var x {1..nx};
# t variable
var t {1..nt};


# Auxiliary variables
var ReR = cos(3*t[1])-x[1]-x[3]*cos(t[1])+x[4]*sin(t[1])
	-x[5]*cos(2*t[1])+x[6]*sin(2*t[1]);
var ImR = sin(3*t[1])-x[2]-x[3]*sin(t[1])-x[4]*cos(t[1])
	-x[5]*sin(2*t[1])-x[6]*cos(2*t[1]);

minimize obj:
	x[7];

subject to tcons:
	ReR^2+ImR^2-x[7] <= 0;
subject to xbound {i in 1..nx-1}:
	-4 <= x[i] <= 4;
subject to bounds {i in 1..nt}:
	0 <= t[i] <= pi4;


###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display x;
display obj;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf, %lf, %lf, %lf, %lf, %lf) obj=%lf\n", 0.368117039, 0.888713155, -1.98904455, -1.98904456, 2.63132741, 1.08993150, 1.470768E-02;
