###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  As described by K.O. Kortanek and H. No in
#      "A central cutting plane algorithm for convex semi-infinite
#               programming problems"
#    SIAM Journal on Optimization, vol. 3, no. 4, pp. 901-918, 1993
#
#   Example 5
#
#    Coded by A. Ismael F. Vaz 03/06/2002  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# PI
param pi := atan(1)*4;

#number of terms
param n := 7;
#number of x vars
param nx := n+1;
#number of t vars
param nt := 1;

# x variables
var x {1..nx};
# t variable
var t {1..nt};


# Auxiliary variables
var ReR = (cos(t[1])-2)/(5-4*cos(t[1]))-sum {j in 1..n} (x[j]*cos((j-1)*t[1]));
var ImR = sin(t[1])/(4*cos(t[1])-5)-sum {j in 1..n} (x[j]*sin((j-1)*t[1]));

minimize obj:
	x[nx];

subject to tcons:
	ReR^2+ImR^2-x[nx] <= 0;
subject to xbound {i in 1..nx-1}:
	-3.1 <= x[i] <= 3.1;
subject to bounds {i in 1..nt}:
	0 <= t[i] <= 2*pi;


###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display x;
display obj;

################################################
# solution of problem presented by the authors #
################################################
#printf "Original Solution (n=5)\n";
#printf "x=(%lf, %lf, %lf, %lf, %lf) obj=%lf\n", -0.5, -0.25, -0.125, -0.0625, -0.416666666E-01, 2.08333333E-02;
printf "Original Solution (n=7)\n";
printf "x=(%lf, %lf, %lf, %lf, %lf, %lf, %lf) obj=%lf\n", -0.5, -0.25, -0.125, -0.0625, -0.312499999E-1, -0.156250000E-1, -0.104166666E-1, 5.2083333333E-03;
