###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  Fuzzy set test problems
#  As described by T. Lon and E. Vercher, "Optimization under uncertainty
#                           and linear semi-infinite programming: a survey",#  
#  in M.A. Goberna and M.A.Lopez (eds.), "Semi-infinite Programming.
#     Recent Advances", Kluwer Academic Publishers, pp. 327-348 (2001)	
#
#   Example pp. 339
#    Coded by Rodolfo Carvalho Carvalhido 10/11/2004 
#      aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# d variable
var d;

# x variables
var x {1..3};
# t variable
var t ;

# c variables
var c1=1.5-0.167*log(1+19.1*t);
var c2=3-0.667*log(1+19.1*t);
var c3=2.2-0.067*log(1+19.1*t);


minimize dp:
	-d;

subject to tcons1:
	-c1*x[1]-c2*x[2]-c3*x[3]+d<=0;

subject to tcons2:
	(2+t)*x[1]+(2*t)*x[2]+(1.5+1.5*t)*x[3]-22-5*log(1-0.55*t)<=0;

subject to tcons3:
	(0.5+0.5*t)*x[1]+(1+t)*x[2]+t*x[3]-40-37.5*log(1-0.55*t)<=0;

subject to tcons4:
	(6+3*t)*x[1]+(18+2*t)*x[2]+(3+4*t)*x[3]-110-17.5*log(1-0.55*t)<=0;

subject to tcons5:
	(6.5+0.5*t)*x[1]+(15+5*t)*x[2]+(8+t)*x[3]-110-17.5*log(1-0.55*t)<=0;
	
subject to bounds:
	0 <= t <= 1;

subject to bounds1 {i in 1..3}:
	x[i] >= 0 ;



###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# this problem have no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display x;
display dp;
