###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#   As described by Chih-Jen Lin, Shu.Cherng Fang and Soon-Yi Wu
#	in "An Unconstrained Convex Programming Approach to Linear
#                 Semi-Infinite Programming",
#    SIAM J. Optim. vol. 8, no. 2, pp. 443-456, May 1998
#
#   Section 5.1 Problem 3
#	This problem is the same as watson8, but an error in the original
#	article has made some confusion. The constraint is also wrong.
#	Initial guess is not the same.
#	Extra bounds in x variables.
#
#    Coded by A. Ismael F. Vaz 11/02/2000  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of x vars
param nx;
#number of t
param nt;

# initial guess
param xinit{1..nx};
param tinit{1..nt};

# x variables
var x {i in 1..nx} := xinit[i];
# t variable
var t {j in 1..nt} := tinit[j];

minimize fx:
	x[1]+(1/2)*x[2]+(1/2)*x[3]+(1/4)*x[4]+(1/4)*x[5]+(1/3)*x[6];

subject to tcons:
	-exp(t[1]^2+t[2]^2)-(x[1]+t[1]*x[2]+t[2]*x[3]+t[1]^2*x[4]+t[1]*t[2]*x[5]+t[2]^2*x[6]) <= 0;

subject to xbounds {i in 1..nx}:
	-10 <= x[i] <= 10;

subject to tbounds {i in 1..nt}:
	0 <= t[i] <= 1;

data;

param nx := 6;
param nt := 2;

# inital guess
param xinit:=
	1 0
	2 0
	3 0
	4 0
	5 0
	6 0;
param tinit:=
	1 0
	2 0;

# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;

################################################
# solution of problem presented by the authors #
################################################
printf "This problem is coded as described in the original article.\n";
printf "Solution presented therein does not corresponds\n";

