###############################################################################
# Objective: Quadratic
# Constraints: Linear
###############################################################################
#
#   As described by Y. Liu, K.L. Teo and S. Ito
#	in "A Dual Parametrization Approach to Linear-Quadratic
#                 Semi-Infinite Programming Problems",
#    Optimization Methods and Software, vol. 10, pp. 471-495
#
#   Example 6.3
#    Coded by A. Ismael F. Vaz 11/02/2000  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# PI
param pi := atan(1)*4;

# number of x vars
param nx;
#number of t
param nt;


# x variables
var x {i in 1..nx};
# t variable
var t {j in 1..nt};

minimize fx:
	(sum {i in 2..nx-1} ((x[i-1]+4*x[i]+x[i+1])*x[i]))+(4*x[1]+x[2])*x[1]+
	  (x[nx-1]+4*x[nx])*x[nx];

subject to tcons1:
	-(sum {i in 1..nx} ((exp(-(t[1]-5*(i/nx))^2))*x[i]))+3+4.5*sin(4.7*pi*(t[1]-1.23)/8) <= 0;

subject to tcons2:
	(sum {i in 1..nx} ((exp(-(t[1]-5*(i/nx))^2))*x[i]))-10-4.5*sin(4.7*pi*(t[1]-1.23)/8) <= 0;

subject to bounds:
	0 <= t[1] <= 5;

data;


# Liu tested this problem with nx=16, but it can be changed
param nx := 16;
param nt := 1;


# solve problem
# no initial guess
option reset_initial_guesses 1;
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf) f=%lf\n", 0.07646, 0.20492, 0.48612, 0.92765, 1.43782, 1.80818, 1.84569, 1.53086, 1.03979, 0.61022, 0.40489, 0.49578, 0.85565, 1.45899, 1.79862, 2.66870, 154.11758;
