###############################################################################
# Objective: Generic
# Constraints: Linear
###############################################################################
#  Watson set of SIP problems
#   As described by G.A. Watson in "Numerical Experiments with Globally
#                 Convergent Methods for Semi-Infinite Programming Problems",
#   Edited in Fiacco, A.V., and K.O. Kortanek (eds.),
#    "Semi-infinite Programming and Applications",
#    Lecture notes in Economics and Mathematical Systems no. 215, pp.193-205
#    Springer Verlag, Berlin (1983)
#
#   Example 5
#    Coded by A. Ismael F. Vaz 24/12/1999  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of x vars
param nx;
#number of t
param nt;

# starting point (ampl needs also a starting point for t)
param xinit{1..nx};
param tinit{1..nt};

# x variables
var x {i in 1..nx} := xinit[i];
# t variable
var t {j in 1..nt} := tinit[j];

minimize fx:
	sum{i in 1..3} (exp(x[i]));

subject to tcons:
	(1/(1+t[1]^2))-x[1]-x[2]*t[1]-x[3]*t[1]^2 <= 0;
subject to bounds:
	0 <= t[1] <= 1;

data;

param nx := 3;
param nt := 1;

# watson starting point
param xinit :=
	1 1
	2 0.5
	3 0;

param tinit :=
	1 0;

# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf,%lf,%lf) f=%lf\n", 1.006593, -0.126881, -0.379712, 4.301191;
